Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1225)

Unified Diff: chrome/browser/file_select_helper.h

Issue 2059533002: Change WebContentsDelegate::RunFileChooser to be frame based. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixes based on reviews. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/extension_view_host.cc ('k') | chrome/browser/file_select_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/file_select_helper.h
diff --git a/chrome/browser/file_select_helper.h b/chrome/browser/file_select_helper.h
index 503acf7bd959ecfebb6634ac82804989db808651..70ae31469084decac927366cf6771beeff24bd77 100644
--- a/chrome/browser/file_select_helper.h
+++ b/chrome/browser/file_select_helper.h
@@ -48,7 +48,7 @@ class FileSelectHelper : public base::RefCountedThreadSafe<
public content::NotificationObserver {
public:
// Show the file chooser dialog.
- static void RunFileChooser(content::WebContents* tab,
+ static void RunFileChooser(content::RenderFrameHost* render_frame_host,
const content::FileChooserParams& params);
// Enumerates all the files in directory.
@@ -89,8 +89,7 @@ class FileSelectHelper : public base::RefCountedThreadSafe<
DISALLOW_COPY_AND_ASSIGN(DirectoryListerDispatchDelegate);
};
- void RunFileChooser(content::RenderViewHost* render_view_host,
- content::WebContents* web_contents,
+ void RunFileChooser(content::RenderFrameHost* render_frame_host,
std::unique_ptr<content::FileChooserParams> params);
void GetFileTypesOnFileThread(
std::unique_ptr<content::FileChooserParams> params);
@@ -221,9 +220,9 @@ class FileSelectHelper : public base::RefCountedThreadSafe<
// Profile used to set/retrieve the last used directory.
Profile* profile_;
// The RenderViewHost and WebContents for the page showing a file dialog
// (may only be one such dialog).
- content::RenderViewHost* render_view_host_;
+ content::RenderFrameHost* render_frame_host_;
content::WebContents* web_contents_;
// Dialog box used for choosing files to upload from file form fields.
« no previous file with comments | « chrome/browser/extensions/extension_view_host.cc ('k') | chrome/browser/file_select_helper.cc » ('j') | no next file with comments »
@@ -221,9 +220,9 @@ class FileSelectHelper : public base::RefCountedThreadSafe<
// Profile used to set/retrieve the last used directory.
Profile* profile_;
- // The RenderViewHost and WebContents for the page showing a file dialog
+ // The RenderFrameHost and WebContents for the page showing a file dialog
// (may only be one such dialog).

Powered by Google App Engine
This is Rietveld 408576698